@@ -1,6 +1,6 @@
-#!/usr/bin/r -t
+#!/usr/bin/env r
 #
-# Copyright (C) 2010 - 2013  Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2010 - 2014  Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -21,15 +21,15 @@
 
 if (.runThisTest) {
 
-.setUp <- Rcpp:::unit_test_setup( "S4.cpp" )
+    .setUp <- Rcpp:::unitTestSetup("S4.cpp")
 
-test.RObject.S4methods <- function(){
+    test.RObject.S4methods <- function(){
 	setClass("track", representation(x="numeric", y="numeric"))
 	tr <- new( "track", x = 2, y = 2 )
-	checkEquals( 
+	checkEquals(
 	    S4_methods(tr),
-		list( TRUE, TRUE, FALSE, 2.0, 2.0 ), 
-		msg = "slot management" )
+            list( TRUE, TRUE, FALSE, 2.0, 2.0 ),
+            msg = "slot management" )
 
 	S4_getslots( tr )
 	checkEquals( tr@x, 10.0 , msg = "slot('x') = 10" )
@@ -38,11 +38,11 @@ test.RObject.S4methods <- function(){
 	checkException( S4_setslots( tr ), msg = "slot does not exist" )
 	checkException( S4_setslots_2( tr ), msg = "slot does not exist" )
 
-}
+    }
 
-test.S4 <- function(){
+    test.S4 <- function(){
 	setClass("track",
-           representation(x="numeric", y="numeric"))
+                 representation(x="numeric", y="numeric"))
 	tr <- new( "track", x = 2, y = 3 )
 	checkEquals( S4_get_slot_x( tr ), 2, msg = "S4( SEXP )" )
 	checkException( S4_get_slot_x( list( x = 2, y = 3 ) ), msg = "not S4" )
@@ -53,10 +53,10 @@ test.S4 <- function(){
 	checkEquals( tr@x, numeric(0) )
 	checkEquals( tr@y, numeric(0) )
 	checkException( S4_ctor( "someclassthatdoesnotexist" ) )
-}
+    }
 
 
-test.S4.is <- function(){
+    test.S4.is <- function(){
 	setClass("track", representation(x="numeric", y="numeric"))
 	setClass("trackCurve", representation(smooth = "numeric"), contains = "track")
 
@@ -69,29 +69,35 @@ test.S4.is <- function(){
 	checkTrue( !S4_is_trackCurve( tr1 ), msg = 'track is not trackCurve' )
 	checkTrue( S4_is_trackCurve( tr2 ), msg = 'trackCurve is trackCurve' )
 
-}
+    }
 
-test.Vector.SlotProxy.ambiguity <- function(){
+    test.Vector.SlotProxy.ambiguity <- function(){
 	setClass("track", representation(x="numeric", y="numeric"))
 	setClass("trackCurve", representation(smooth = "numeric"), contains = "track")
 
 	tr1 <- new( "track", x = 2, y = 3 )
 	checkEquals( S4_get_slot_x(tr1), 2, "Vector( SlotProxy ) ambiguity" )
 
-}
+    }
 
-test.Vector.AttributeProxy.ambiguity <- function(){
+    test.Vector.AttributeProxy.ambiguity <- function(){
 	x <- 1:10
 	attr( x, "foo" ) <- "bar"
 
 	checkEquals( S4_get_attr_x(x), "bar", "Vector( AttributeProxy ) ambiguity" )
 
-}
+    }
 
-test.S4.dotdataslot <- function(){
+    test.S4.dotdataslot <- function(){
 	setClass( "Foo", contains = "character", representation( x = "numeric" ) )
 	foo <- S4_dotdata( new( "Foo", "bla", x = 10 ) )
 	checkEquals( as.character( foo) , "foooo" )
-}
+    }
+
+    test.S4.proxycoerce <- function() {
+        setClass("Foo", list(data="integer"))
+        foo <- new("Foo", data=1:3)
+        checkEquals( S4_proxycoerce(foo), c(1, 2, 3) )
+    }
 
 }
